@@ -21,9 +21,9 @@
  */
 
 
-void call_dialog_key_input (GtkWidget * widget, GdkEventKey * event);
+gboolean call_dialog_key_input (GtkWidget * widget, GdkEventKey * event);
 void init_call_dialog ();
 void set_values ();
 void clear_values ();
 void toggle_call_dialog ();
-
+void log_values ();
